#ifndef GRAPHICS_VIEW_H
#define GRAPHICS_VIEW_H

/*
**  view.h
**
**  (C) Copyright 2003 Rocklyte Systems.
**      All Rights Reserved.
*/

#ifndef MAIN_H
#include <pandora/main.h>
#endif

/*****************************************************************************
** View flags.
*/

#define VWF_MULTISELECT  0x00000001  /* Allow multiple object selections in the view */
#define VWF_NOICONS      0x00000002  /* Do not load any icons */
#define VWF_HAIRLINES    0x00000004  /* Show hairlines between columns */
#define VWF_SENSITIVE    0x00000008  /* Children are activated on single clicks */
#define VWF_PRESERVEBKGD 0x00000010  /* Preserve the background when scrolling */
#define VWF_INVISIBLE    0x00000020  /* The view is currently invisible */

/*****************************************************************************
** List options.
*/

#define VIEW_LIST      0   /* Standard list view with small icons, arranged from top to bottom */
#define VIEW_ICON      1   /* Similar to list-view but with large icons, arranged from left to right */
#define VIEW_TREE      3   /* Nodes are arranged into expandable tree items */
#define VIEW_COLUMN    4   /* Long list with detail columns */
#define VIEW_LONGLIST  5   /* Same as the standard list view but doesn't wrap at the bottom */

/*****************************************************************************
** View methods.
*/

#define MT_HideColumn      -1
#define MT_ShowColumn      -2
#define MT_SelectAll       -3
#define MT_InvertSelection -4
#define MT_SortColumn      -5
#define MT_SortColumnIndex -6
#define MT_SelectItem      -7
#define MT_SetViewItem     -8
#define MT_RemoveViewItem  -9
#define MT_CacheViewIcon   -10
#define MT_RemoveViewTag   -11

struct mtCacheViewIcon {
   STRING Icon;
};

struct mtRemoveViewItem {
   LONG ID;
   LONG TagIndex;
};

struct mtRemoveViewTag {
   LONG TagIndex;
};

struct mtSelectItem {
   STRING Tag;
   STRING Item;
};

struct mtSetViewItem {
   LONG   ID;
   LONG   TagIndex;
   STRING Tag;
   STRING Attrib;
   STRING Value;
};

struct mtSortColumn {
   STRING Column;
   LONG   Descending;
};

struct mtSortColumnIndex {
   LONG Column;
   LONG Descending;
};

#endif /* GRAPHICS_VIEW_H */
