#ifndef MODULES_KERNELBASE_H
#define MODULES_KERNELBASE_H

/*
**  kernelbase.h
**
**  Definition of the base structure for making calls to the kernel.
**
**  (C) Copyright 1996-2004 Rocklyte Systems.
**      All Rights Reserved.
*/

#ifndef MAIN_H
#include <pandora/main.h>
#endif

#ifndef MODULES_KERNEL_H
#include <pandora/modules/kernel.h>
#endif

/*****************************************************************************
** Kernel Function Base structure.
*/

struct KernelBase {
   ERROR     (*AccessMemory)(MEMORYID, LONG, APTR);
   ERROR     (*Action)(ACTIONID, APTR, APTR);
   struct ActionTable * (*ActionList)(void);
   ERROR     (*_ActionMsg)(ACTIONID, OBJECTID, APTR, MEMORYID, CLASSID);
   ERROR     (*ActionTag)(ACTIONID, APTR, ...);
   ERROR     (*AllocateClassID)(STRING Name, CLASSID *);
   LONG      (*AllocateID)(LONG);
   ERROR     (*AllocMemory)(LONG, LONG, APTR, MEMORYID *);
   ERROR     (*AccessObject)(OBJECTID, LONG, OBJECTPTR *);
   ERROR     (*ListTasks)(LONG, struct ListTasks **);
   ERROR     (*CheckAction)(APTR, LONG);
   ERROR     (*CheckMemoryExists)(MEMORYID);
   ERROR     (*CheckObjectExists)(OBJECTID, STRING);
   ERROR     (*CloneMemory)(APTR, LONG, APTR *, MEMORYID *);
   ERROR     (*CreateObjectTags)(CLASSID, LONG, APTR, OBJECTID *, LONG, ...);
   APTR      (*CurrentContext)(void);
   ERROR     (*ListObjects)(CLASSID, LONG, struct ObjectInfo **);
   LONG      (*DebugState)(LONG, LONG);
   void      (*DPrintFTags)(STRING, APTR, ...);
   ERROR     (*FastFindObject)(STRING, CLASSID, OBJECTID *, LONG, LONG *);
   OBJECTPTR (*FindClass)(CLASSID, OBJECTPTR);
   LONG      (*FindObject)(STRING, CLASSID, OBJECTID **, LONG *);
   ERROR     (*ReleaseObject)(APTR);
   ERROR     (*FreeMemory)(APTR);
   ERROR     (*FreeMemoryID)(MEMORYID);
   LONG      (*GetClassID)(OBJECTID);
   OBJECTID  (*GetOwnerID)(OBJECTID);
   LONG      (*GetField)(APTR, LONG, LONG, APTR);
   ERROR     (*GetFieldVariable)(APTR, STRING, STRING, LONG);
   ERROR     (*GetFieldTags)(APTR, ...);
   ERROR     (*GetName)(APTR, STRING, LONG);
   ERROR     (*ListChildren)(OBJECTID, struct ChildEntry *, LONG *);
   ERROR     (*ListMemory)(LONG, struct ListMemory **);
   ERROR     (*RegisterFD)(LONG, APTR);
   ERROR     (*ManageAction)(ACTIONID, APTR);
   ERROR     (*MemoryIDInfo)(MEMORYID, LONG, struct MemInfo *);
   ERROR     (*MemoryPtrInfo)(APTR, LONG, struct MemInfo *);
   ERROR     (*_NewObject)(CLASSID, LONG, APTR, OBJECTID *, STRING);
   void      (*NotifySubscribers)(APTR, LONG, APTR, LONG);
   ERROR     (*ObjectError)(APTR, LONG, ERROR);
   ERROR     (*ObtainMethod)(APTR, ACTIONID, void **);
   ERROR     (*ProcessMessages)(struct NextMsg *, LONG);
   LONG      (*RandomNumber)(LONG);
   ERROR     (*ReallocMemory)(APTR, LONG, APTR, MEMORYID *);
   ERROR     (*GetMessage)(MEMORYID, LONG, LONG, APTR, LONG);
   MEMORYID  (*ReleaseMemory)(APTR);
   LONG      (*ResolveClassName)(STRING);
   ERROR     (*ResolveFieldTags)(STRING, ...);
   void      (*SelfDestruct)(void);
   ERROR     (*SendError)(LONG, LONG);
   ERROR     (*SendMessage)(MEMORYID, LONG, LONG, APTR, LONG);
   ERROR     (*SetOwner)(APTR, APTR);
   APTR      (*SetContext)(APTR);
   ERROR     (*SetField)(APTR, FIELD, LONG, APTR);
   ERROR     (*SetFieldTags)(APTR, ...);
   ERROR     (*SetFieldVariable)(APTR, STRING, STRING);
   ERROR     (*SetName)(APTR, STRING);
   void      (*StepBack)(void);
   LONG      (*StrCompare)(STRING, STRING, LONG, LONG);
   ERROR     (*SubscribeAction)(APTR, FIELD, APTR);
   ERROR     (*SubscribeChannel)(APTR, APTR);
   ERROR     (*SubscribeField)(APTR, FIELD, APTR);
   ERROR     (*SubscribeTimer)(OBJECTID, LONG);
   LONG      (*TotalChildren)(OBJECTID);
   ERROR     (*UnsubscribeAction)(APTR, LONG, OBJECTID);
   ERROR     (*UnsubscribeChannel)(APTR, OBJECTID);
   ERROR     (*UnsubscribeField)(APTR, FIELD, OBJECTID);
   ERROR     (*UnsubscribeTimer)(OBJECTID);
   void      (*WaitTime)(LONG, LONG);
   ERROR     (*WatchPublicMemory)(APTR, MEMORYID, LONG);
   ERROR     (*MessageHook)(APTR, LONG);
   LARGE     (*_GetResource)(LONG);
   LARGE     (*SetResource)(LONG, LARGE);
   ERROR     (*ScanMessages)(APTR, LONG *, LONG, APTR, LONG);
   ERROR     (*Forbid)(void);
   ERROR     (*Permit)(void);
   ERROR     (*CopyMemory)(APTR, APTR, LONG);
   ERROR     (*ClearMemory)(APTR, LONG);
   ERROR     (*AccessSemaphore)(LONG, LONG, LONG);
   ERROR     (*AllocSemaphore)(STRING, LONG, LONG, LONG *);
   ERROR     (*FreeSemaphore)(LONG);
   ERROR     (*ReleaseSemaphore)(LONG, LONG);
   ERROR     (*_SubscribeActionTags)(APTR, APTR, ACTIONID, ...);
   void      (*PrintDiagnosis)(LONG);
   LARGE     (*SystemTime)(void);
   ERROR     (*_UpdateMessage)(APTR, LONG, LONG, APTR, LONG);
   ERROR     (*AddMsgHandler)(LONG (*Handler)(LONG, LONG, APTR, LONG));
   ERROR     (*RemoveMsgHandler)(LONG (*Handler)(LONG, LONG, APTR, LONG));
   ERROR     (*FindPrivateObject)(STRING, OBJECTPTR *);
   void      (*DeregisterFD)(LONG);
};

#endif /* MODULES_KERNELBASE_H */
